==> k3sup-0.12.8.tar.gz: k3sup-0.12.8/.github/ISSUE_TEMPLATE.md <==
## Are you a GitHub Sponsor?

Only sponsors may open issues, all other issues (unless previously discussed agreed upon with a maintainer) will be closed without comment.

Check at [https://github.com/sponsors/alexellis](https://github.com/sponsors/alexellis)

<!--- Provide a general summary of the issue in the Title above -->

## Why do you need this?

<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->
<!--- Is this request for work, a client, your employer or for fun? -->

## Expected Behaviour
<!--- If you're describing a bug, tell us what should happen -->
<!--- If you're suggesting a change/improvement, tell us how it should work -->

## Current Behaviour
<!--- If describing a bug, tell us what happens instead of the expected behavior -->
<!--- If suggesting a change/improvement, explain the difference from current behavior -->

## Possible Solution
<!--- Not obligatory, but suggest a fix/reason for the bug, -->
<!--- or ideas how to implement the addition or change -->


## Steps to Reproduce
<!--- Provide a link to a live example, or an unambiguous set of steps to -->
<!--- reproduce this bug. Include code to reproduce, if relevant -->
1.
2.
3.
4.

## Your Environment

* k3sup version:

```
k3sup version
```

* What Kubernetes distribution, client and server version are you using?

```
kubectl version
```

* What OS or type or VM are you using for your cluster? Where is it hosted? (for `k3sup install/join`):

* Operating System and version (e.g. Linux, Windows, MacOS):

```
uname -a

cat /etc/os-release
```

## "Be part of the solution"

Subject to approval, are you willing to work on a Pull Request for this issue or feature request?

- [ ] Yes
- [ ] No

==> k3sup-0.13.5.tar.gz: k3sup-0.13.5/.github/ISSUE_TEMPLATE.md <==
<!--- Provide a general summary of the issue in the Title above -->

## Why do you need this?

<!--- How has this issue affected you? What are you trying to accomplish? -->
<!--- Providing context helps us come up with a solution that is most useful in the real world -->
<!--- Is this request for work, a client, your employer or for fun? -->

## Expected Behaviour
<!--- If you're describing a bug, tell us what should happen -->
<!--- If you're suggesting a change/improvement, tell us how it should work -->

## Current Behaviour
<!--- If describing a bug, tell us what happens instead of the expected behavior -->
<!--- If suggesting a change/improvement, explain the difference from current behavior -->

## Possible Solution
<!--- Not obligatory, but suggest a fix/reason for the bug, -->
<!--- or ideas how to implement the addition or change -->


## Steps to Reproduce
<!--- Provide a link to a live example, or an unambiguous set of steps to -->
<!--- reproduce this bug. Include code to reproduce, if relevant -->
1.
2.
3.
4.

## Your Environment

* k3sup version:

```
k3sup version
```

* What Kubernetes distribution, client and server version are you using?

```
kubectl version
```

* What OS or type or VM are you using for your cluster? Where is it hosted? (for `k3sup install/join`):

* Operating System and version (e.g. Linux, Windows, MacOS):

```
uname -a

cat /etc/os-release
```

## Do you want to work on this?

Subject to design approval, are you willing to work on a Pull Request for this issue or feature request?

- [ ] Yes
- [ ] No
